/**
 * @packageDocumentation
 *
 * Use the `identify` function to add support for the [Identify protocol](https://github.com/libp2p/specs/blob/master/identify/README.md) to libp2p.
 *
 * @example
 *
 * ```typescript
 * import { createLibp2p } from 'libp2p'
 * import { identify } from '@libp2p/identify'
 *
 * const node = await createLibp2p({
 *   // ...other options
 *   services: {
 *     identify: identify()
 *   }
 * })
 * ```
 */
import { MULTICODEC_IDENTIFY } from './consts.js';
import { Identify as IdentifyClass } from './identify.js';
/**
 * The protocols the Identify service supports
 */
export const multicodecs = {
    IDENTIFY: MULTICODEC_IDENTIFY
};
export function identify(init = {}) {
    return (components) => new IdentifyClass(components, init);
}
//# sourceMappingURL=index.js.map